All pastes #1050142 Raw Edit

Untitled

public text v1 · immutable
#1050142 ·published 2008-06-18 14:08 UTC
rendered paste body
*** Options which should probably stay ***


  -h, --help       This help
required

  -R, --repackage  Repackage contents of pkg/ without building
required because no one is perfect

  -e, --noextract  Do not extract source files (use existing src/ dir)
like -R, this can save a lot of time

  -s, --syncdeps   Install missing dependencies with pacman
I always need that, maybe it could even be the default?

      --noconfirm      Do not ask for confirmation when resolving dependencies
      --noprogressbar  Do not show a progress bar when downloading files
These two pacman options might be useful, though I am not perfectly sure and I
never used them

      --holdver    Prevent automatic version bumping for development PKGBUILDs

  -o, --nobuild    Download and extract files only


*** Options which are practical but are just a simple shortcut ***


  -f, --force      Overwrite existing package
simple rm command

  -i, --install    Install package after successful build
simple pacman -U command

  -L, --log        Log package build process
why not just use tee manually on whole makepkg output?
if that does not work fine, then this option is ok I guess


*** Options which are practical but could be done outside of makepkg ***


      --source     Do not build package; generate a source-only tarball
pratical but could be done easily with an external script

  -g, --geninteg   Generate integrity checks for source files
practical but could be done easily with an external script


*** Options which could maybe go? ***


  -A, --ignorearch Ignore incomplete arch field in PKGBUILD
arch field should be completed, not ignored

  -c, --clean      Clean up work files after build
  -C, --cleancache Clean up source files from the cache
I actually hate these two options since they can't be run afterwards (after the
package has been built). It is easily done manually anyway.

  -d, --nodeps     Skip all dependency checks
Skipping dependency checks is bad ;)

  -m, --nocolor    Disable colorized output messages
Is that useful?

  -p <buildscript> Use an alternate build script (instead of 'PKGBUILD')
Is that useful?

  -r, --rmdeps     Remove installed dependencies after a successful build
this option does not even work correctly (see ML)
better just use pacman -Qtd

      --asroot     Allow makepkg to run as root user
why do we need an option for that?